# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Applicant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, created_at=None, delete_at=None, href=None, title=None, first_name=None, middle_name=None, last_name=None, email=None, gender=None, dob=None, telephone=None, mobile=None, country=None, sandbox=None, nationality=None, mothers_maiden_name=None, country_of_birth=None, town_of_birth=None, previous_last_name=None, addresses=None, id_numbers=None):
        """
        Applicant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'created_at': 'datetime',
            'delete_at': 'datetime',
            'href': 'str',
            'title': 'str',
            'first_name': 'str',
            'middle_name': 'str',
            'last_name': 'str',
            'email': 'str',
            'gender': 'str',
            'dob': 'date',
            'telephone': 'str',
            'mobile': 'str',
            'country': 'str',
            'sandbox': 'bool',
            'nationality': 'str',
            'mothers_maiden_name': 'str',
            'country_of_birth': 'str',
            'town_of_birth': 'str',
            'previous_last_name': 'str',
            'addresses': 'list[Address]',
            'id_numbers': 'list[IdNumber]'
        }

        self.attribute_map = {
            'id': 'id',
            'created_at': 'created_at',
            'delete_at': 'delete_at',
            'href': 'href',
            'title': 'title',
            'first_name': 'first_name',
            'middle_name': 'middle_name',
            'last_name': 'last_name',
            'email': 'email',
            'gender': 'gender',
            'dob': 'dob',
            'telephone': 'telephone',
            'mobile': 'mobile',
            'country': 'country',
            'sandbox': 'sandbox',
            'nationality': 'nationality',
            'mothers_maiden_name': 'mothers_maiden_name',
            'country_of_birth': 'country_of_birth',
            'town_of_birth': 'town_of_birth',
            'previous_last_name': 'previous_last_name',
            'addresses': 'addresses',
            'id_numbers': 'id_numbers'
        }

        self._id = id
        self._created_at = created_at
        self._delete_at = delete_at
        self._href = href
        self._title = title
        self._first_name = first_name
        self._middle_name = middle_name
        self._last_name = last_name
        self._email = email
        self._gender = gender
        self._dob = dob
        self._telephone = telephone
        self._mobile = mobile
        self._country = country
        self._sandbox = sandbox
        self._nationality = nationality
        self._mothers_maiden_name = mothers_maiden_name
        self._country_of_birth = country_of_birth
        self._town_of_birth = town_of_birth
        self._previous_last_name = previous_last_name
        self._addresses = addresses
        self._id_numbers = id_numbers


    @property
    def id(self):
        """
        Gets the id of this Applicant.
        The unique identifier for the applicant

        :return: The id of this Applicant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Applicant.
        The unique identifier for the applicant

        :param id: The id of this Applicant.
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """
        Gets the created_at of this Applicant.
        The date and time when this applicant was created

        :return: The created_at of this Applicant.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this Applicant.
        The date and time when this applicant was created

        :param created_at: The created_at of this Applicant.
        :type: datetime
        """

        self._created_at = created_at

    @property
    def delete_at(self):
        """
        Gets the delete_at of this Applicant.
        The date and time when this applicant is scheduled to be deleted, or null if the applicant is not scheduled to be deleted

        :return: The delete_at of this Applicant.
        :rtype: datetime
        """
        return self._delete_at

    @delete_at.setter
    def delete_at(self, delete_at):
        """
        Sets the delete_at of this Applicant.
        The date and time when this applicant is scheduled to be deleted, or null if the applicant is not scheduled to be deleted

        :param delete_at: The delete_at of this Applicant.
        :type: datetime
        """

        self._delete_at = delete_at

    @property
    def href(self):
        """
        Gets the href of this Applicant.
        The uri of this resource

        :return: The href of this Applicant.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this Applicant.
        The uri of this resource

        :param href: The href of this Applicant.
        :type: str
        """

        self._href = href

    @property
    def title(self):
        """
        Gets the title of this Applicant.
        The applicant’s title

        :return: The title of this Applicant.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this Applicant.
        The applicant’s title

        :param title: The title of this Applicant.
        :type: str
        """

        self._title = title

    @property
    def first_name(self):
        """
        Gets the first_name of this Applicant.
        The applicant’s first name

        :return: The first_name of this Applicant.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this Applicant.
        The applicant’s first name

        :param first_name: The first_name of this Applicant.
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")

        self._first_name = first_name

    @property
    def middle_name(self):
        """
        Gets the middle_name of this Applicant.
        The applicant’s middle name(s) or initial

        :return: The middle_name of this Applicant.
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """
        Sets the middle_name of this Applicant.
        The applicant’s middle name(s) or initial

        :param middle_name: The middle_name of this Applicant.
        :type: str
        """

        self._middle_name = middle_name

    @property
    def last_name(self):
        """
        Gets the last_name of this Applicant.
        The applicant’s surname

        :return: The last_name of this Applicant.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this Applicant.
        The applicant’s surname

        :param last_name: The last_name of this Applicant.
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")

        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this Applicant.
        The applicant’s email address

        :return: The email of this Applicant.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this Applicant.
        The applicant’s email address

        :param email: The email of this Applicant.
        :type: str
        """

        self._email = email

    @property
    def gender(self):
        """
        Gets the gender of this Applicant.
        The applicant’s gender. Valid values are male and female

        :return: The gender of this Applicant.
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """
        Sets the gender of this Applicant.
        The applicant’s gender. Valid values are male and female

        :param gender: The gender of this Applicant.
        :type: str
        """

        self._gender = gender

    @property
    def dob(self):
        """
        Gets the dob of this Applicant.
        The applicant’s date of birth

        :return: The dob of this Applicant.
        :rtype: date
        """
        return self._dob

    @dob.setter
    def dob(self, dob):
        """
        Sets the dob of this Applicant.
        The applicant’s date of birth

        :param dob: The dob of this Applicant.
        :type: date
        """

        self._dob = dob

    @property
    def telephone(self):
        """
        Gets the telephone of this Applicant.
        The applicant’s landline phone number

        :return: The telephone of this Applicant.
        :rtype: str
        """
        return self._telephone

    @telephone.setter
    def telephone(self, telephone):
        """
        Sets the telephone of this Applicant.
        The applicant’s landline phone number

        :param telephone: The telephone of this Applicant.
        :type: str
        """

        self._telephone = telephone

    @property
    def mobile(self):
        """
        Gets the mobile of this Applicant.
        The applicant’s mobile phone number

        :return: The mobile of this Applicant.
        :rtype: str
        """
        return self._mobile

    @mobile.setter
    def mobile(self, mobile):
        """
        Sets the mobile of this Applicant.
        The applicant’s mobile phone number

        :param mobile: The mobile of this Applicant.
        :type: str
        """

        self._mobile = mobile

    @property
    def country(self):
        """
        Gets the country of this Applicant.
        The country where this applicant will be checked. This must be a three-letter ISO code e.g. GBR or USA

        :return: The country of this Applicant.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Applicant.
        The country where this applicant will be checked. This must be a three-letter ISO code e.g. GBR or USA

        :param country: The country of this Applicant.
        :type: str
        """

        self._country = country

    @property
    def sandbox(self):
        """
        Gets the sandbox of this Applicant.


        :return: The sandbox of this Applicant.
        :rtype: bool
        """
        return self._sandbox

    @sandbox.setter
    def sandbox(self, sandbox):
        """
        Sets the sandbox of this Applicant.


        :param sandbox: The sandbox of this Applicant.
        :type: bool
        """

        self._sandbox = sandbox

    @property
    def nationality(self):
        """
        Gets the nationality of this Applicant.
        The applicant's nationality. This must be a three-letter ISO code e.g. GBR or USA

        :return: The nationality of this Applicant.
        :rtype: str
        """
        return self._nationality

    @nationality.setter
    def nationality(self, nationality):
        """
        Sets the nationality of this Applicant.
        The applicant's nationality. This must be a three-letter ISO code e.g. GBR or USA

        :param nationality: The nationality of this Applicant.
        :type: str
        """

        self._nationality = nationality

    @property
    def mothers_maiden_name(self):
        """
        Gets the mothers_maiden_name of this Applicant.
        The applicant’s mothers maiden name

        :return: The mothers_maiden_name of this Applicant.
        :rtype: str
        """
        return self._mothers_maiden_name

    @mothers_maiden_name.setter
    def mothers_maiden_name(self, mothers_maiden_name):
        """
        Sets the mothers_maiden_name of this Applicant.
        The applicant’s mothers maiden name

        :param mothers_maiden_name: The mothers_maiden_name of this Applicant.
        :type: str
        """

        self._mothers_maiden_name = mothers_maiden_name

    @property
    def country_of_birth(self):
        """
        Gets the country_of_birth of this Applicant.
        The applicant’s country of birth

        :return: The country_of_birth of this Applicant.
        :rtype: str
        """
        return self._country_of_birth

    @country_of_birth.setter
    def country_of_birth(self, country_of_birth):
        """
        Sets the country_of_birth of this Applicant.
        The applicant’s country of birth

        :param country_of_birth: The country_of_birth of this Applicant.
        :type: str
        """

        self._country_of_birth = country_of_birth

    @property
    def town_of_birth(self):
        """
        Gets the town_of_birth of this Applicant.
        The applicant’s town of birth

        :return: The town_of_birth of this Applicant.
        :rtype: str
        """
        return self._town_of_birth

    @town_of_birth.setter
    def town_of_birth(self, town_of_birth):
        """
        Sets the town_of_birth of this Applicant.
        The applicant’s town of birth

        :param town_of_birth: The town_of_birth of this Applicant.
        :type: str
        """

        self._town_of_birth = town_of_birth

    @property
    def previous_last_name(self):
        """
        Gets the previous_last_name of this Applicant.
        The applicant’s previous last name

        :return: The previous_last_name of this Applicant.
        :rtype: str
        """
        return self._previous_last_name

    @previous_last_name.setter
    def previous_last_name(self, previous_last_name):
        """
        Sets the previous_last_name of this Applicant.
        The applicant’s previous last name

        :param previous_last_name: The previous_last_name of this Applicant.
        :type: str
        """

        self._previous_last_name = previous_last_name

    @property
    def addresses(self):
        """
        Gets the addresses of this Applicant.


        :return: The addresses of this Applicant.
        :rtype: list[Address]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this Applicant.


        :param addresses: The addresses of this Applicant.
        :type: list[Address]
        """

        self._addresses = addresses

    @property
    def id_numbers(self):
        """
        Gets the id_numbers of this Applicant.


        :return: The id_numbers of this Applicant.
        :rtype: list[IdNumber]
        """
        return self._id_numbers

    @id_numbers.setter
    def id_numbers(self, id_numbers):
        """
        Sets the id_numbers of this Applicant.


        :param id_numbers: The id_numbers of this Applicant.
        :type: list[IdNumber]
        """

        self._id_numbers = id_numbers

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class DefaultApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def cancel_report(self, check_id, report_id, **kwargs):
        """
        This endpoint is for cancelling individual paused reports.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.cancel_report(check_id, report_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :param str report_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.cancel_report_with_http_info(check_id, report_id, **kwargs)
        else:
            (data) = self.cancel_report_with_http_info(check_id, report_id, **kwargs)
            return data

    def cancel_report_with_http_info(self, check_id, report_id, **kwargs):
        """
        This endpoint is for cancelling individual paused reports.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.cancel_report_with_http_info(check_id, report_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :param str report_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['check_id', 'report_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in params) or (params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `cancel_report`")
        # verify the required parameter 'report_id' is set
        if ('report_id' not in params) or (params['report_id'] is None):
            raise ValueError("Missing the required parameter `report_id` when calling `cancel_report`")


        collection_formats = {}

        resource_path = '/checks/{check_id}/reports/{report_id}/cancel'.replace('{format}', 'json')
        path_params = {}
        if 'check_id' in params:
            path_params['check_id'] = params['check_id']
        if 'report_id' in params:
            path_params['report_id'] = params['report_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def create_applicant(self, **kwargs):
        """
        Create Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_applicant(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Applicant data: 
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_applicant_with_http_info(**kwargs)
        else:
            (data) = self.create_applicant_with_http_info(**kwargs)
            return data

    def create_applicant_with_http_info(self, **kwargs):
        """
        Create Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_applicant_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Applicant data: 
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_applicant" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        resource_path = '/applicants'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Applicant',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def create_check(self, applicant_id, **kwargs):
        """
        Create a check
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_check(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param CheckCreationRequest data: 
        :return: Check
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_check_with_http_info(applicant_id, **kwargs)
        else:
            (data) = self.create_check_with_http_info(applicant_id, **kwargs)
            return data

    def create_check_with_http_info(self, applicant_id, **kwargs):
        """
        Create a check
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_check_with_http_info(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param CheckCreationRequest data: 
        :return: Check
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id', 'data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `create_check`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}/checks'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Check',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def create_webhook(self, **kwargs):
        """
        Create a webhook
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_webhook(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Webhook data: 
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_webhook_with_http_info(**kwargs)
        else:
            (data) = self.create_webhook_with_http_info(**kwargs)
            return data

    def create_webhook_with_http_info(self, **kwargs):
        """
        Create a webhook
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_webhook_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Webhook data: 
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_webhook" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        resource_path = '/webhooks'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Webhook',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def destroy_applicant(self, applicant_id, **kwargs):
        """
        Delete Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.destroy_applicant(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.destroy_applicant_with_http_info(applicant_id, **kwargs)
        else:
            (data) = self.destroy_applicant_with_http_info(applicant_id, **kwargs)
            return data

    def destroy_applicant_with_http_info(self, applicant_id, **kwargs):
        """
        Delete Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.destroy_applicant_with_http_info(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method destroy_applicant" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `destroy_applicant`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def download_document(self, applicant_id, document_id, **kwargs):
        """
        Download a documents raw data
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.download_document(applicant_id, document_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param str document_id:  (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.download_document_with_http_info(applicant_id, document_id, **kwargs)
        else:
            (data) = self.download_document_with_http_info(applicant_id, document_id, **kwargs)
            return data

    def download_document_with_http_info(self, applicant_id, document_id, **kwargs):
        """
        Download a documents raw data
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.download_document_with_http_info(applicant_id, document_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param str document_id:  (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id', 'document_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `download_document`")
        # verify the required parameter 'document_id' is set
        if ('document_id' not in params) or (params['document_id'] is None):
            raise ValueError("Missing the required parameter `document_id` when calling `download_document`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}/documents/{document_id}/download'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']
        if 'document_id' in params:
            path_params['document_id'] = params['document_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['image/png', 'image/jpeg', 'applicant/pdf'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='file',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def download_live_photo(self, live_photo_id, **kwargs):
        """
        Download live photo
        Live photos are downloaded using this endpoint.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.download_live_photo(live_photo_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str live_photo_id: The live photo’s unique identifier. (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.download_live_photo_with_http_info(live_photo_id, **kwargs)
        else:
            (data) = self.download_live_photo_with_http_info(live_photo_id, **kwargs)
            return data

    def download_live_photo_with_http_info(self, live_photo_id, **kwargs):
        """
        Download live photo
        Live photos are downloaded using this endpoint.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.download_live_photo_with_http_info(live_photo_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str live_photo_id: The live photo’s unique identifier. (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['live_photo_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_live_photo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'live_photo_id' is set
        if ('live_photo_id' not in params) or (params['live_photo_id'] is None):
            raise ValueError("Missing the required parameter `live_photo_id` when calling `download_live_photo`")


        collection_formats = {}

        resource_path = '/live_photos/{live_photo_id}/download'.replace('{format}', 'json')
        path_params = {}
        if 'live_photo_id' in params:
            path_params['live_photo_id'] = params['live_photo_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='file',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def find_addresses(self, postcode, **kwargs):
        """
        Search for addresses by postcode
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_addresses(postcode, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postcode:  (required)
        :return: GenericAddressesList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_addresses_with_http_info(postcode, **kwargs)
        else:
            (data) = self.find_addresses_with_http_info(postcode, **kwargs)
            return data

    def find_addresses_with_http_info(self, postcode, **kwargs):
        """
        Search for addresses by postcode
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_addresses_with_http_info(postcode, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postcode:  (required)
        :return: GenericAddressesList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postcode']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_addresses" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postcode' is set
        if ('postcode' not in params) or (params['postcode'] is None):
            raise ValueError("Missing the required parameter `postcode` when calling `find_addresses`")


        collection_formats = {}

        resource_path = '/addresses/pick'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'postcode' in params:
            query_params['postcode'] = params['postcode']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GenericAddressesList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def find_applicant(self, applicant_id, **kwargs):
        """
        Retrieve Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_applicant(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_applicant_with_http_info(applicant_id, **kwargs)
        else:
            (data) = self.find_applicant_with_http_info(applicant_id, **kwargs)
            return data

    def find_applicant_with_http_info(self, applicant_id, **kwargs):
        """
        Retrieve Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_applicant_with_http_info(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_applicant" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `find_applicant`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Applicant',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def find_check(self, applicant_id, check_id, **kwargs):
        """
        Retrieve a Check
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_check(applicant_id, check_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param str check_id:  (required)
        :return: Check
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_check_with_http_info(applicant_id, check_id, **kwargs)
        else:
            (data) = self.find_check_with_http_info(applicant_id, check_id, **kwargs)
            return data

    def find_check_with_http_info(self, applicant_id, check_id, **kwargs):
        """
        Retrieve a Check
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_check_with_http_info(applicant_id, check_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param str check_id:  (required)
        :return: Check
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id', 'check_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `find_check`")
        # verify the required parameter 'check_id' is set
        if ('check_id' not in params) or (params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `find_check`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}/checks/{check_id}'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']
        if 'check_id' in params:
            path_params['check_id'] = params['check_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Check',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def find_document(self, applicant_id, document_id, **kwargs):
        """
        A single document can be retrieved by calling this endpoint with the document’s unique identifier.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_document(applicant_id, document_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param str document_id:  (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_document_with_http_info(applicant_id, document_id, **kwargs)
        else:
            (data) = self.find_document_with_http_info(applicant_id, document_id, **kwargs)
            return data

    def find_document_with_http_info(self, applicant_id, document_id, **kwargs):
        """
        A single document can be retrieved by calling this endpoint with the document’s unique identifier.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_document_with_http_info(applicant_id, document_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param str document_id:  (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id', 'document_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `find_document`")
        # verify the required parameter 'document_id' is set
        if ('document_id' not in params) or (params['document_id'] is None):
            raise ValueError("Missing the required parameter `document_id` when calling `find_document`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}/documents/{document_id}'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']
        if 'document_id' in params:
            path_params['document_id'] = params['document_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Document',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def find_live_photo(self, live_photo_id, **kwargs):
        """
        Retrieve live photo
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_live_photo(live_photo_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str live_photo_id: The live photo’s unique identifier. (required)
        :return: LivePhoto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_live_photo_with_http_info(live_photo_id, **kwargs)
        else:
            (data) = self.find_live_photo_with_http_info(live_photo_id, **kwargs)
            return data

    def find_live_photo_with_http_info(self, live_photo_id, **kwargs):
        """
        Retrieve live photo
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_live_photo_with_http_info(live_photo_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str live_photo_id: The live photo’s unique identifier. (required)
        :return: LivePhoto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['live_photo_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_live_photo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'live_photo_id' is set
        if ('live_photo_id' not in params) or (params['live_photo_id'] is None):
            raise ValueError("Missing the required parameter `live_photo_id` when calling `find_live_photo`")


        collection_formats = {}

        resource_path = '/live_photos/{live_photo_id}'.replace('{format}', 'json')
        path_params = {}
        if 'live_photo_id' in params:
            path_params['live_photo_id'] = params['live_photo_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='LivePhoto',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def find_report(self, check_id, report_id, **kwargs):
        """
        A single report can be retrieved using this endpoint with the corresponding unique identifier.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_report(check_id, report_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :param str report_id:  (required)
        :return: Report
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_report_with_http_info(check_id, report_id, **kwargs)
        else:
            (data) = self.find_report_with_http_info(check_id, report_id, **kwargs)
            return data

    def find_report_with_http_info(self, check_id, report_id, **kwargs):
        """
        A single report can be retrieved using this endpoint with the corresponding unique identifier.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_report_with_http_info(check_id, report_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :param str report_id:  (required)
        :return: Report
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['check_id', 'report_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in params) or (params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `find_report`")
        # verify the required parameter 'report_id' is set
        if ('report_id' not in params) or (params['report_id'] is None):
            raise ValueError("Missing the required parameter `report_id` when calling `find_report`")


        collection_formats = {}

        resource_path = '/checks/{check_id}/reports/{report_id}'.replace('{format}', 'json')
        path_params = {}
        if 'check_id' in params:
            path_params['check_id'] = params['check_id']
        if 'report_id' in params:
            path_params['report_id'] = params['report_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Report',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def find_report_type_group(self, report_type_group_id, **kwargs):
        """
        Retrieve single report type group object
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_report_type_group(report_type_group_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str report_type_group_id:  (required)
        :return: ReportTypeGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_report_type_group_with_http_info(report_type_group_id, **kwargs)
        else:
            (data) = self.find_report_type_group_with_http_info(report_type_group_id, **kwargs)
            return data

    def find_report_type_group_with_http_info(self, report_type_group_id, **kwargs):
        """
        Retrieve single report type group object
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_report_type_group_with_http_info(report_type_group_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str report_type_group_id:  (required)
        :return: ReportTypeGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['report_type_group_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_report_type_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'report_type_group_id' is set
        if ('report_type_group_id' not in params) or (params['report_type_group_id'] is None):
            raise ValueError("Missing the required parameter `report_type_group_id` when calling `find_report_type_group`")


        collection_formats = {}

        resource_path = '/report_type_groups/{report_type_group_id}'.replace('{format}', 'json')
        path_params = {}
        if 'report_type_group_id' in params:
            path_params['report_type_group_id'] = params['report_type_group_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ReportTypeGroup',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def find_webhook(self, webhook_id, **kwargs):
        """
        Retrieve a Webhook
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_webhook(webhook_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str webhook_id:  (required)
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_webhook_with_http_info(webhook_id, **kwargs)
        else:
            (data) = self.find_webhook_with_http_info(webhook_id, **kwargs)
            return data

    def find_webhook_with_http_info(self, webhook_id, **kwargs):
        """
        Retrieve a Webhook
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_webhook_with_http_info(webhook_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str webhook_id:  (required)
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['webhook_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_webhook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'webhook_id' is set
        if ('webhook_id' not in params) or (params['webhook_id'] is None):
            raise ValueError("Missing the required parameter `webhook_id` when calling `find_webhook`")


        collection_formats = {}

        resource_path = '/webhooks/{webhook_id}'.replace('{format}', 'json')
        path_params = {}
        if 'webhook_id' in params:
            path_params['webhook_id'] = params['webhook_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Webhook',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def list_applicants(self, **kwargs):
        """
        List Applicants
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_applicants(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page: The page to return. Defaults to the first page if omitted. The first page is `page=1`
        :param int per_page: The number of objects per page. Defaults to 20 if omitted.
        :param bool include_deleted: Whether to also include applicants scheduled for deletion. Defaults to false if omitted.
        :return: ApplicantsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_applicants_with_http_info(**kwargs)
        else:
            (data) = self.list_applicants_with_http_info(**kwargs)
            return data

    def list_applicants_with_http_info(self, **kwargs):
        """
        List Applicants
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_applicants_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page: The page to return. Defaults to the first page if omitted. The first page is `page=1`
        :param int per_page: The number of objects per page. Defaults to 20 if omitted.
        :param bool include_deleted: Whether to also include applicants scheduled for deletion. Defaults to false if omitted.
        :return: ApplicantsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'per_page', 'include_deleted']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_applicants" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        resource_path = '/applicants'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page' in params:
            query_params['page'] = params['page']
        if 'per_page' in params:
            query_params['per_page'] = params['per_page']
        if 'include_deleted' in params:
            query_params['include_deleted'] = params['include_deleted']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ApplicantsList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def list_checks(self, applicant_id, **kwargs):
        """
        Retrieve Checks
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_checks(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param int page: The page to return. Defaults to the first page if omitted. The first page is `page=1`
        :param int per_page: The number of objects per page. Defaults to 20 if omitted.
        :return: ChecksList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_checks_with_http_info(applicant_id, **kwargs)
        else:
            (data) = self.list_checks_with_http_info(applicant_id, **kwargs)
            return data

    def list_checks_with_http_info(self, applicant_id, **kwargs):
        """
        Retrieve Checks
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_checks_with_http_info(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param int page: The page to return. Defaults to the first page if omitted. The first page is `page=1`
        :param int per_page: The number of objects per page. Defaults to 20 if omitted.
        :return: ChecksList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id', 'page', 'per_page']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_checks" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `list_checks`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}/checks'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']

        query_params = {}
        if 'page' in params:
            query_params['page'] = params['page']
        if 'per_page' in params:
            query_params['per_page'] = params['per_page']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ChecksList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def list_documents(self, applicant_id, **kwargs):
        """
        List documents
        All documents belonging to an applicant can be listed from this endpoint

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_documents(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :return: DocumentsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_documents_with_http_info(applicant_id, **kwargs)
        else:
            (data) = self.list_documents_with_http_info(applicant_id, **kwargs)
            return data

    def list_documents_with_http_info(self, applicant_id, **kwargs):
        """
        List documents
        All documents belonging to an applicant can be listed from this endpoint

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_documents_with_http_info(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :return: DocumentsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_documents" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `list_documents`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}/documents'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DocumentsList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def list_live_photos(self, applicant_id, **kwargs):
        """
        List live photos
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_live_photos(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id: The id of the applicant the live photos belongs to. (required)
        :return: LivePhotosList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_live_photos_with_http_info(applicant_id, **kwargs)
        else:
            (data) = self.list_live_photos_with_http_info(applicant_id, **kwargs)
            return data

    def list_live_photos_with_http_info(self, applicant_id, **kwargs):
        """
        List live photos
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_live_photos_with_http_info(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id: The id of the applicant the live photos belongs to. (required)
        :return: LivePhotosList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_live_photos" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `list_live_photos`")


        collection_formats = {}

        resource_path = '/live_photos'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'applicant_id' in params:
            query_params['applicant_id'] = params['applicant_id']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='LivePhotosList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def list_report_type_groups(self, **kwargs):
        """
        Retrieve all report type groups
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_report_type_groups(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: ReportTypeGroupsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_report_type_groups_with_http_info(**kwargs)
        else:
            (data) = self.list_report_type_groups_with_http_info(**kwargs)
            return data

    def list_report_type_groups_with_http_info(self, **kwargs):
        """
        Retrieve all report type groups
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_report_type_groups_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: ReportTypeGroupsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_report_type_groups" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        resource_path = '/report_type_groups'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ReportTypeGroupsList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def list_reports(self, check_id, **kwargs):
        """
        All the reports belonging to a particular check can be listed from this endpoint.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_reports(check_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :return: ReportsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_reports_with_http_info(check_id, **kwargs)
        else:
            (data) = self.list_reports_with_http_info(check_id, **kwargs)
            return data

    def list_reports_with_http_info(self, check_id, **kwargs):
        """
        All the reports belonging to a particular check can be listed from this endpoint.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_reports_with_http_info(check_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :return: ReportsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['check_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_reports" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in params) or (params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `list_reports`")


        collection_formats = {}

        resource_path = '/checks/{check_id}/reports'.replace('{format}', 'json')
        path_params = {}
        if 'check_id' in params:
            path_params['check_id'] = params['check_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ReportsList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def list_webhooks(self, **kwargs):
        """
        List webhooks
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_webhooks(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: WebhooksList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_webhooks_with_http_info(**kwargs)
        else:
            (data) = self.list_webhooks_with_http_info(**kwargs)
            return data

    def list_webhooks_with_http_info(self, **kwargs):
        """
        List webhooks
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_webhooks_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: WebhooksList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_webhooks" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        resource_path = '/webhooks'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebhooksList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def restore_applicant(self, applicant_id, **kwargs):
        """
        Restore Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.restore_applicant(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.restore_applicant_with_http_info(applicant_id, **kwargs)
        else:
            (data) = self.restore_applicant_with_http_info(applicant_id, **kwargs)
            return data

    def restore_applicant_with_http_info(self, applicant_id, **kwargs):
        """
        Restore Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.restore_applicant_with_http_info(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method restore_applicant" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `restore_applicant`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}/restore'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def resume_check(self, check_id, **kwargs):
        """
        Resume a Check
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.resume_check(check_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.resume_check_with_http_info(check_id, **kwargs)
        else:
            (data) = self.resume_check_with_http_info(check_id, **kwargs)
            return data

    def resume_check_with_http_info(self, check_id, **kwargs):
        """
        Resume a Check
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.resume_check_with_http_info(check_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['check_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in params) or (params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `resume_check`")


        collection_formats = {}

        resource_path = '/checks/{check_id}/resume'.replace('{format}', 'json')
        path_params = {}
        if 'check_id' in params:
            path_params['check_id'] = params['check_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def resume_report(self, check_id, report_id, **kwargs):
        """
        This endpoint is for resuming individual paused reports.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.resume_report(check_id, report_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :param str report_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.resume_report_with_http_info(check_id, report_id, **kwargs)
        else:
            (data) = self.resume_report_with_http_info(check_id, report_id, **kwargs)
            return data

    def resume_report_with_http_info(self, check_id, report_id, **kwargs):
        """
        This endpoint is for resuming individual paused reports.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.resume_report_with_http_info(check_id, report_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str check_id:  (required)
        :param str report_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['check_id', 'report_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in params) or (params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `resume_report`")
        # verify the required parameter 'report_id' is set
        if ('report_id' not in params) or (params['report_id'] is None):
            raise ValueError("Missing the required parameter `report_id` when calling `resume_report`")


        collection_formats = {}

        resource_path = '/checks/{check_id}/reports/{report_id}/resume'.replace('{format}', 'json')
        path_params = {}
        if 'check_id' in params:
            path_params['check_id'] = params['check_id']
        if 'report_id' in params:
            path_params['report_id'] = params['report_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def update_applicant(self, applicant_id, **kwargs):
        """
        Update Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_applicant(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param Applicant data: 
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_applicant_with_http_info(applicant_id, **kwargs)
        else:
            (data) = self.update_applicant_with_http_info(applicant_id, **kwargs)
            return data

    def update_applicant_with_http_info(self, applicant_id, **kwargs):
        """
        Update Applicant
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_applicant_with_http_info(applicant_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param Applicant data: 
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id', 'data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_applicant" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `update_applicant`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Applicant',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def upload_document(self, applicant_id, type, **kwargs):
        """
        Upload a document
        Documents are uploaded using this endpoint. Along with the file upload the relevant document type must be specified. Documents must be uploaded as a multipart form. The valid file types are: jpg, png and pdf. The file size must be between 2KB and 3MB. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.upload_document(applicant_id, type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param str type:  (required)
        :param str side: 
        :param file file: 
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.upload_document_with_http_info(applicant_id, type, **kwargs)
        else:
            (data) = self.upload_document_with_http_info(applicant_id, type, **kwargs)
            return data

    def upload_document_with_http_info(self, applicant_id, type, **kwargs):
        """
        Upload a document
        Documents are uploaded using this endpoint. Along with the file upload the relevant document type must be specified. Documents must be uploaded as a multipart form. The valid file types are: jpg, png and pdf. The file size must be between 2KB and 3MB. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.upload_document_with_http_info(applicant_id, type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id:  (required)
        :param str type:  (required)
        :param str side: 
        :param file file: 
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id', 'type', 'side', 'file']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `upload_document`")
        # verify the required parameter 'type' is set
        if ('type' not in params) or (params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `upload_document`")


        collection_formats = {}

        resource_path = '/applicants/{applicant_id}/documents'.replace('{format}', 'json')
        path_params = {}
        if 'applicant_id' in params:
            path_params['applicant_id'] = params['applicant_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'type' in params:
            form_params.append(('type', params['type']))
        if 'side' in params:
            form_params.append(('side', params['side']))
        if 'file' in params:
            local_var_files['file'] = params['file']

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data'])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Document',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)

    def upload_live_photo(self, applicant_id, file, **kwargs):
        """
        Upload live photo
        You can upload live photos to this endpoint. Like document upload, files must be uploaded as a multipart form. Valid file types are jpg, png and pdf. The file size must be between 32KB and 10MB. Live photos are validated at the point of upload to check that they contain exactly one face. This validation can be disabled by setting the advanced_validation argument to false. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.upload_live_photo(applicant_id, file, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id: The applicant_id to associate the live photo to. (required)
        :param file file: The file to be uploaded. (required)
        :param bool advanced_validation: Validates that the live photo contains exactly one face.
        :return: LivePhoto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.upload_live_photo_with_http_info(applicant_id, file, **kwargs)
        else:
            (data) = self.upload_live_photo_with_http_info(applicant_id, file, **kwargs)
            return data

    def upload_live_photo_with_http_info(self, applicant_id, file, **kwargs):
        """
        Upload live photo
        You can upload live photos to this endpoint. Like document upload, files must be uploaded as a multipart form. Valid file types are jpg, png and pdf. The file size must be between 32KB and 10MB. Live photos are validated at the point of upload to check that they contain exactly one face. This validation can be disabled by setting the advanced_validation argument to false. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.upload_live_photo_with_http_info(applicant_id, file, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str applicant_id: The applicant_id to associate the live photo to. (required)
        :param file file: The file to be uploaded. (required)
        :param bool advanced_validation: Validates that the live photo contains exactly one face.
        :return: LivePhoto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['applicant_id', 'file', 'advanced_validation']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_live_photo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in params) or (params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `upload_live_photo`")
        # verify the required parameter 'file' is set
        if ('file' not in params) or (params['file'] is None):
            raise ValueError("Missing the required parameter `file` when calling `upload_live_photo`")


        collection_formats = {}

        resource_path = '/live_photos'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'applicant_id' in params:
            form_params.append(('applicant_id', params['applicant_id']))
        if 'file' in params:
            local_var_files['file'] = params['file']
        if 'advanced_validation' in params:
            form_params.append(('advanced_validation', params['advanced_validation']))

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data'])

        # Authentication setting
        auth_settings = ['Token']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='LivePhoto',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            collection_formats=collection_formats)



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import onfido
from onfido.rest import ApiException
from onfido.models.document import Document


class TestDocument(unittest.TestCase):
    """ Document unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDocument(self):
        """
        Test Document
        """
        model = onfido.models.document.Document()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import onfido
from onfido.rest import ApiException
from onfido.apis.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """ DefaultApi unit test stubs """

    def setUp(self):
        self.api = onfido.apis.default_api.DefaultApi()

    def tearDown(self):
        pass

    def test_cancel_report(self):
        """
        Test case for cancel_report

        This endpoint is for cancelling individual paused reports.
        """
        pass

    def test_create_applicant(self):
        """
        Test case for create_applicant

        Create Applicant
        """
        pass

    def test_create_check(self):
        """
        Test case for create_check

        Create a check
        """
        pass

    def test_create_webhook(self):
        """
        Test case for create_webhook

        Create a webhook
        """
        pass

    def test_destroy_applicant(self):
        """
        Test case for destroy_applicant

        Delete Applicant
        """
        pass

    def test_download_document(self):
        """
        Test case for download_document

        Download a documents raw data
        """
        pass

    def test_download_live_photo(self):
        """
        Test case for download_live_photo

        Download live photo
        """
        pass

    def test_find_addresses(self):
        """
        Test case for find_addresses

        Search for addresses by postcode
        """
        pass

    def test_find_applicant(self):
        """
        Test case for find_applicant

        Retrieve Applicant
        """
        pass

    def test_find_check(self):
        """
        Test case for find_check

        Retrieve a Check
        """
        pass

    def test_find_document(self):
        """
        Test case for find_document

        A single document can be retrieved by calling this endpoint with the document’s unique identifier.
        """
        pass

    def test_find_live_photo(self):
        """
        Test case for find_live_photo

        Retrieve live photo
        """
        pass

    def test_find_report(self):
        """
        Test case for find_report

        A single report can be retrieved using this endpoint with the corresponding unique identifier.
        """
        pass

    def test_find_report_type_group(self):
        """
        Test case for find_report_type_group

        Retrieve single report type group object
        """
        pass

    def test_find_webhook(self):
        """
        Test case for find_webhook

        Retrieve a Webhook
        """
        pass

    def test_list_applicants(self):
        """
        Test case for list_applicants

        List Applicants
        """
        pass

    def test_list_checks(self):
        """
        Test case for list_checks

        Retrieve Checks
        """
        pass

    def test_list_documents(self):
        """
        Test case for list_documents

        List documents
        """
        pass

    def test_list_live_photos(self):
        """
        Test case for list_live_photos

        List live photos
        """
        pass

    def test_list_report_type_groups(self):
        """
        Test case for list_report_type_groups

        Retrieve all report type groups
        """
        pass

    def test_list_reports(self):
        """
        Test case for list_reports

        All the reports belonging to a particular check can be listed from this endpoint.
        """
        pass

    def test_list_webhooks(self):
        """
        Test case for list_webhooks

        List webhooks
        """
        pass

    def test_restore_applicant(self):
        """
        Test case for restore_applicant

        Restore Applicant
        """
        pass

    def test_resume_check(self):
        """
        Test case for resume_check

        Resume a Check
        """
        pass

    def test_resume_report(self):
        """
        Test case for resume_report

        This endpoint is for resuming individual paused reports.
        """
        pass

    def test_update_applicant(self):
        """
        Test case for update_applicant

        Update Applicant
        """
        pass

    def test_upload_document(self):
        """
        Test case for upload_document

        Upload a document
        """
        pass

    def test_upload_live_photo(self):
        """
        Test case for upload_live_photo

        Upload live photo
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Report(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, created_at=None, href=None, name=None, status=None, result=None, sub_result=None, variant=None, options=None, breakdown=None, properties=None, documents=None):
        """
        Report - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'created_at': 'datetime',
            'href': 'str',
            'name': 'str',
            'status': 'str',
            'result': 'str',
            'sub_result': 'str',
            'variant': 'str',
            'options': 'object',
            'breakdown': 'object',
            'properties': 'object',
            'documents': 'list[object]'
        }

        self.attribute_map = {
            'id': 'id',
            'created_at': 'created_at',
            'href': 'href',
            'name': 'name',
            'status': 'status',
            'result': 'result',
            'sub_result': 'sub_result',
            'variant': 'variant',
            'options': 'options',
            'breakdown': 'breakdown',
            'properties': 'properties',
            'documents': 'documents'
        }

        self._id = id
        self._created_at = created_at
        self._href = href
        self._name = name
        self._status = status
        self._result = result
        self._sub_result = sub_result
        self._variant = variant
        self._options = options
        self._breakdown = breakdown
        self._properties = properties
        self._documents = documents


    @property
    def id(self):
        """
        Gets the id of this Report.
        The unique identifier for the report.

        :return: The id of this Report.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Report.
        The unique identifier for the report.

        :param id: The id of this Report.
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """
        Gets the created_at of this Report.
        The date and time at which the report was first initiated.

        :return: The created_at of this Report.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this Report.
        The date and time at which the report was first initiated.

        :param created_at: The created_at of this Report.
        :type: datetime
        """

        self._created_at = created_at

    @property
    def href(self):
        """
        Gets the href of this Report.
        The API endpoint to retrieve the report.

        :return: The href of this Report.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this Report.
        The API endpoint to retrieve the report.

        :param href: The href of this Report.
        :type: str
        """

        self._href = href

    @property
    def name(self):
        """
        Gets the name of this Report.
        Report type string identifier.

        :return: The name of this Report.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Report.
        Report type string identifier.

        :param name: The name of this Report.
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """
        Gets the status of this Report.
        The current state of the report in the checking process.

        :return: The status of this Report.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Report.
        The current state of the report in the checking process.

        :param status: The status of this Report.
        :type: str
        """

        self._status = status

    @property
    def result(self):
        """
        Gets the result of this Report.
        The result of the report.

        :return: The result of this Report.
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """
        Sets the result of this Report.
        The result of the report.

        :param result: The result of this Report.
        :type: str
        """

        self._result = result

    @property
    def sub_result(self):
        """
        Gets the sub_result of this Report.
        The sub_result of the report. It gives a more detailed result for document reports only, and will be null otherwise.

        :return: The sub_result of this Report.
        :rtype: str
        """
        return self._sub_result

    @sub_result.setter
    def sub_result(self, sub_result):
        """
        Sets the sub_result of this Report.
        The sub_result of the report. It gives a more detailed result for document reports only, and will be null otherwise.

        :param sub_result: The sub_result of this Report.
        :type: str
        """

        self._sub_result = sub_result

    @property
    def variant(self):
        """
        Gets the variant of this Report.
        Report variant string identifier. Some reports e.g. criminal_history have sub-types, which are identified by this field.

        :return: The variant of this Report.
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """
        Sets the variant of this Report.
        Report variant string identifier. Some reports e.g. criminal_history have sub-types, which are identified by this field.

        :param variant: The variant of this Report.
        :type: str
        """

        self._variant = variant

    @property
    def options(self):
        """
        Gets the options of this Report.
        Report options. Some reports e.g. criminal_history expose additional options.

        :return: The options of this Report.
        :rtype: object
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this Report.
        Report options. Some reports e.g. criminal_history expose additional options.

        :param options: The options of this Report.
        :type: object
        """

        self._options = options

    @property
    def breakdown(self):
        """
        Gets the breakdown of this Report.
        The details of the report. This is specific to each type of report.

        :return: The breakdown of this Report.
        :rtype: object
        """
        return self._breakdown

    @breakdown.setter
    def breakdown(self, breakdown):
        """
        Sets the breakdown of this Report.
        The details of the report. This is specific to each type of report.

        :param breakdown: The breakdown of this Report.
        :type: object
        """

        self._breakdown = breakdown

    @property
    def properties(self):
        """
        Gets the properties of this Report.
        The properties associated with the report, if any.

        :return: The properties of this Report.
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this Report.
        The properties associated with the report, if any.

        :param properties: The properties of this Report.
        :type: object
        """

        self._properties = properties

    @property
    def documents(self):
        """
        Gets the documents of this Report.
        Array of objects with document ids that were used in the Onfido engine. [ONLY USED IN A DOCUMENT CHECK]

        :return: The documents of this Report.
        :rtype: list[object]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """
        Sets the documents of this Report.
        Array of objects with document ids that were used in the Onfido engine. [ONLY USED IN A DOCUMENT CHECK]

        :param documents: The documents of this Report.
        :type: list[object]
        """

        self._documents = documents

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class CheckCreationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, type=None, redirect_uri=None, reports=None, report_type_groups=None, criminal_history_report_details=None, tags=None, suppress_form_emails=None, charge_applicant_for_check=None, brand_id=None, async=None):
        """
        CheckCreationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'redirect_uri': 'str',
            'reports': 'list[Report]',
            'report_type_groups': 'list[str]',
            'criminal_history_report_details': 'object',
            'tags': 'list[str]',
            'suppress_form_emails': 'bool',
            'charge_applicant_for_check': 'bool',
            'brand_id': 'str',
            'async': 'bool'
        }

        self.attribute_map = {
            'type': 'type',
            'redirect_uri': 'redirect_uri',
            'reports': 'reports',
            'report_type_groups': 'report_type_groups',
            'criminal_history_report_details': 'criminal_history_report_details',
            'tags': 'tags',
            'suppress_form_emails': 'suppress_form_emails',
            'charge_applicant_for_check': 'charge_applicant_for_check',
            'brand_id': 'brand_id',
            'async': 'async'
        }

        self._type = type
        self._redirect_uri = redirect_uri
        self._reports = reports
        self._report_type_groups = report_type_groups
        self._criminal_history_report_details = criminal_history_report_details
        self._tags = tags
        self._suppress_form_emails = suppress_form_emails
        self._charge_applicant_for_check = charge_applicant_for_check
        self._brand_id = brand_id
        self._async = async


    @property
    def type(self):
        """
        Gets the type of this CheckCreationRequest.
        standard or express

        :return: The type of this CheckCreationRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CheckCreationRequest.
        standard or express

        :param type: The type of this CheckCreationRequest.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def redirect_uri(self):
        """
        Gets the redirect_uri of this CheckCreationRequest.
        For standard checks, redirect to this URI when the applicant has submitted their data.

        :return: The redirect_uri of this CheckCreationRequest.
        :rtype: str
        """
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, redirect_uri):
        """
        Sets the redirect_uri of this CheckCreationRequest.
        For standard checks, redirect to this URI when the applicant has submitted their data.

        :param redirect_uri: The redirect_uri of this CheckCreationRequest.
        :type: str
        """

        self._redirect_uri = redirect_uri

    @property
    def reports(self):
        """
        Gets the reports of this CheckCreationRequest.
        Array of Reports being requested for this check.

        :return: The reports of this CheckCreationRequest.
        :rtype: list[Report]
        """
        return self._reports

    @reports.setter
    def reports(self, reports):
        """
        Sets the reports of this CheckCreationRequest.
        Array of Reports being requested for this check.

        :param reports: The reports of this CheckCreationRequest.
        :type: list[Report]
        """

        self._reports = reports

    @property
    def report_type_groups(self):
        """
        Gets the report_type_groups of this CheckCreationRequest.
        Array containing ids of the Report type groups being requested for.

        :return: The report_type_groups of this CheckCreationRequest.
        :rtype: list[str]
        """
        return self._report_type_groups

    @report_type_groups.setter
    def report_type_groups(self, report_type_groups):
        """
        Sets the report_type_groups of this CheckCreationRequest.
        Array containing ids of the Report type groups being requested for.

        :param report_type_groups: The report_type_groups of this CheckCreationRequest.
        :type: list[str]
        """

        self._report_type_groups = report_type_groups

    @property
    def criminal_history_report_details(self):
        """
        Gets the criminal_history_report_details of this CheckCreationRequest.
        Hash containing properties required for standard or enhanced UK criminal history reports. Only required for checks containing these specific reports. See Criminal history report details arguments.

        :return: The criminal_history_report_details of this CheckCreationRequest.
        :rtype: object
        """
        return self._criminal_history_report_details

    @criminal_history_report_details.setter
    def criminal_history_report_details(self, criminal_history_report_details):
        """
        Sets the criminal_history_report_details of this CheckCreationRequest.
        Hash containing properties required for standard or enhanced UK criminal history reports. Only required for checks containing these specific reports. See Criminal history report details arguments.

        :param criminal_history_report_details: The criminal_history_report_details of this CheckCreationRequest.
        :type: object
        """

        self._criminal_history_report_details = criminal_history_report_details

    @property
    def tags(self):
        """
        Gets the tags of this CheckCreationRequest.
        Array of tags being assigned to this check.

        :return: The tags of this CheckCreationRequest.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this CheckCreationRequest.
        Array of tags being assigned to this check.

        :param tags: The tags of this CheckCreationRequest.
        :type: list[str]
        """

        self._tags = tags

    @property
    def suppress_form_emails(self):
        """
        Gets the suppress_form_emails of this CheckCreationRequest.
        For standard checks, applicant form will not be automatically sent if this is set to true. You can manually send the form at any time after the check has been created, using the link found in the form_uri attribute of the check object. Defaults to false (i.e., form will be sent automatically by default).

        :return: The suppress_form_emails of this CheckCreationRequest.
        :rtype: bool
        """
        return self._suppress_form_emails

    @suppress_form_emails.setter
    def suppress_form_emails(self, suppress_form_emails):
        """
        Sets the suppress_form_emails of this CheckCreationRequest.
        For standard checks, applicant form will not be automatically sent if this is set to true. You can manually send the form at any time after the check has been created, using the link found in the form_uri attribute of the check object. Defaults to false (i.e., form will be sent automatically by default).

        :param suppress_form_emails: The suppress_form_emails of this CheckCreationRequest.
        :type: bool
        """

        self._suppress_form_emails = suppress_form_emails

    @property
    def charge_applicant_for_check(self):
        """
        Gets the charge_applicant_for_check of this CheckCreationRequest.
        For standard checks, applicants will be presented with a mandatory payment screen before they can submit the applicant form, if this is set to true. In this case, your account will not be charged. Defaults to false.

        :return: The charge_applicant_for_check of this CheckCreationRequest.
        :rtype: bool
        """
        return self._charge_applicant_for_check

    @charge_applicant_for_check.setter
    def charge_applicant_for_check(self, charge_applicant_for_check):
        """
        Sets the charge_applicant_for_check of this CheckCreationRequest.
        For standard checks, applicants will be presented with a mandatory payment screen before they can submit the applicant form, if this is set to true. In this case, your account will not be charged. Defaults to false.

        :param charge_applicant_for_check: The charge_applicant_for_check of this CheckCreationRequest.
        :type: bool
        """

        self._charge_applicant_for_check = charge_applicant_for_check

    @property
    def brand_id(self):
        """
        Gets the brand_id of this CheckCreationRequest.
        ID of the brand under which the check should be conducted. Optional.

        :return: The brand_id of this CheckCreationRequest.
        :rtype: str
        """
        return self._brand_id

    @brand_id.setter
    def brand_id(self, brand_id):
        """
        Sets the brand_id of this CheckCreationRequest.
        ID of the brand under which the check should be conducted. Optional.

        :param brand_id: The brand_id of this CheckCreationRequest.
        :type: str
        """

        self._brand_id = brand_id

    @property
    def async(self):
        """
        Gets the async of this CheckCreationRequest.
        If this is set to true, checks will be queued for processing and no reports will be returned immediately. Defaults to false

        :return: The async of this CheckCreationRequest.
        :rtype: bool
        """
        return self._async

    @async.setter
    def async(self, async):
        """
        Sets the async of this CheckCreationRequest.
        If this is set to true, checks will be queued for processing and no reports will be returned immediately. Defaults to false

        :param async: The async of this CheckCreationRequest.
        :type: bool
        """

        self._async = async

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Check(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, created_at=None, href=None, type=None, status=None, tags=None, result=None, download_uri=None, form_uri=None, redirect_uri=None, results_uri=None, reports=None):
        """
        Check - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'created_at': 'datetime',
            'href': 'str',
            'type': 'str',
            'status': 'str',
            'tags': 'list[str]',
            'result': 'str',
            'download_uri': 'str',
            'form_uri': 'str',
            'redirect_uri': 'str',
            'results_uri': 'str',
            'reports': 'list[object]'
        }

        self.attribute_map = {
            'id': 'id',
            'created_at': 'created_at',
            'href': 'href',
            'type': 'type',
            'status': 'status',
            'tags': 'tags',
            'result': 'result',
            'download_uri': 'download_uri',
            'form_uri': 'form_uri',
            'redirect_uri': 'redirect_uri',
            'results_uri': 'results_uri',
            'reports': 'reports'
        }

        self._id = id
        self._created_at = created_at
        self._href = href
        self._type = type
        self._status = status
        self._tags = tags
        self._result = result
        self._download_uri = download_uri
        self._form_uri = form_uri
        self._redirect_uri = redirect_uri
        self._results_uri = results_uri
        self._reports = reports


    @property
    def id(self):
        """
        Gets the id of this Check.


        :return: The id of this Check.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Check.


        :param id: The id of this Check.
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """
        Gets the created_at of this Check.
        The date and time when this check was created.

        :return: The created_at of this Check.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this Check.
        The date and time when this check was created.

        :param created_at: The created_at of this Check.
        :type: datetime
        """

        self._created_at = created_at

    @property
    def href(self):
        """
        Gets the href of this Check.
        The uri of this resource.

        :return: The href of this Check.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this Check.
        The uri of this resource.

        :param href: The href of this Check.
        :type: str
        """

        self._href = href

    @property
    def type(self):
        """
        Gets the type of this Check.
        The type of the check: standard or express.

        :return: The type of this Check.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Check.
        The type of the check: standard or express.

        :param type: The type of this Check.
        :type: str
        """

        self._type = type

    @property
    def status(self):
        """
        Gets the status of this Check.
        The current state of the check in the checking process.

        :return: The status of this Check.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Check.
        The current state of the check in the checking process.

        :param status: The status of this Check.
        :type: str
        """

        self._status = status

    @property
    def tags(self):
        """
        Gets the tags of this Check.
        A list of tags associated with this check.

        :return: The tags of this Check.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Check.
        A list of tags associated with this check.

        :param tags: The tags of this Check.
        :type: list[str]
        """

        self._tags = tags

    @property
    def result(self):
        """
        Gets the result of this Check.
        The overall result of the check, based on the results of the constituent reports.

        :return: The result of this Check.
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """
        Sets the result of this Check.
        The overall result of the check, based on the results of the constituent reports.

        :param result: The result of this Check.
        :type: str
        """

        self._result = result

    @property
    def download_uri(self):
        """
        Gets the download_uri of this Check.


        :return: The download_uri of this Check.
        :rtype: str
        """
        return self._download_uri

    @download_uri.setter
    def download_uri(self, download_uri):
        """
        Sets the download_uri of this Check.


        :param download_uri: The download_uri of this Check.
        :type: str
        """

        self._download_uri = download_uri

    @property
    def form_uri(self):
        """
        Gets the form_uri of this Check.


        :return: The form_uri of this Check.
        :rtype: str
        """
        return self._form_uri

    @form_uri.setter
    def form_uri(self, form_uri):
        """
        Sets the form_uri of this Check.


        :param form_uri: The form_uri of this Check.
        :type: str
        """

        self._form_uri = form_uri

    @property
    def redirect_uri(self):
        """
        Gets the redirect_uri of this Check.


        :return: The redirect_uri of this Check.
        :rtype: str
        """
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, redirect_uri):
        """
        Sets the redirect_uri of this Check.


        :param redirect_uri: The redirect_uri of this Check.
        :type: str
        """

        self._redirect_uri = redirect_uri

    @property
    def results_uri(self):
        """
        Gets the results_uri of this Check.


        :return: The results_uri of this Check.
        :rtype: str
        """
        return self._results_uri

    @results_uri.setter
    def results_uri(self, results_uri):
        """
        Sets the results_uri of this Check.


        :param results_uri: The results_uri of this Check.
        :type: str
        """

        self._results_uri = results_uri

    @property
    def reports(self):
        """
        Gets the reports of this Check.


        :return: The reports of this Check.
        :rtype: list[object]
        """
        return self._reports

    @reports.setter
    def reports(self, reports):
        """
        Sets the reports of this Check.


        :param reports: The reports of this Check.
        :type: list[object]
        """

        self._reports = reports

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Webhook(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, url=None, token=None, enabled=None, href=None, environments=None, events=None):
        """
        Webhook - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'url': 'str',
            'token': 'str',
            'enabled': 'bool',
            'href': 'str',
            'environments': 'list[str]',
            'events': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'url': 'url',
            'token': 'token',
            'enabled': 'enabled',
            'href': 'href',
            'environments': 'environments',
            'events': 'events'
        }

        self._id = id
        self._url = url
        self._token = token
        self._enabled = enabled
        self._href = href
        self._environments = environments
        self._events = events


    @property
    def id(self):
        """
        Gets the id of this Webhook.
        The unique identifier of the webhook.

        :return: The id of this Webhook.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Webhook.
        The unique identifier of the webhook.

        :param id: The id of this Webhook.
        :type: str
        """

        self._id = id

    @property
    def url(self):
        """
        Gets the url of this Webhook.
        The url of the webhook

        :return: The url of this Webhook.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this Webhook.
        The url of the webhook

        :param url: The url of this Webhook.
        :type: str
        """

        self._url = url

    @property
    def token(self):
        """
        Gets the token of this Webhook.
        Webhook secret token used to sign the webhook's payload

        :return: The token of this Webhook.
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """
        Sets the token of this Webhook.
        Webhook secret token used to sign the webhook's payload

        :param token: The token of this Webhook.
        :type: str
        """

        self._token = token

    @property
    def enabled(self):
        """
        Gets the enabled of this Webhook.
        Determine if the webhook is active.

        :return: The enabled of this Webhook.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this Webhook.
        Determine if the webhook is active.

        :param enabled: The enabled of this Webhook.
        :type: bool
        """

        self._enabled = enabled

    @property
    def href(self):
        """
        Gets the href of this Webhook.
        The API endpoint to retrieve the webhook.

        :return: The href of this Webhook.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this Webhook.
        The API endpoint to retrieve the webhook.

        :param href: The href of this Webhook.
        :type: str
        """

        self._href = href

    @property
    def environments(self):
        """
        Gets the environments of this Webhook.
        The environments from which the webhook will receive events.

        :return: The environments of this Webhook.
        :rtype: list[str]
        """
        return self._environments

    @environments.setter
    def environments(self, environments):
        """
        Sets the environments of this Webhook.
        The environments from which the webhook will receive events.

        :param environments: The environments of this Webhook.
        :type: list[str]
        """

        self._environments = environments

    @property
    def events(self):
        """
        Gets the events of this Webhook.
        The events that will be published to the webhook.

        :return: The events of this Webhook.
        :rtype: list[str]
        """
        return self._events

    @events.setter
    def events(self, events):
        """
        Sets the events of this Webhook.
        The events that will be published to the webhook.

        :param events: The events of this Webhook.
        :type: list[str]
        """

        self._events = events

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
